
/*
 * Superimpose spectra created with CreateHisto.C
 * May 2017.
 */


void SuperimpMay2017(double ROImin = 5505, double ROImax = 6695, double xmin = 5000, double xmax = 7500, bool veto = true)
{
    // output 
    TString ofname = "vk.eps";

    // input
    TString ifname = "his.root";

    // files
    vector<TString> hname;
    hname.push_back("forbidden"); 
    hname.push_back("allowed");
    hname.push_back("summing");
    hname.push_back("pileup");
    hname.push_back("backgr");
    if (veto) {
        for (auto& hn : hname) hn += "Veto";
    }
    
    // line width
    vector<Int_t> lineWidth;
    lineWidth.push_back(2); 
    lineWidth.push_back(1);
    lineWidth.push_back(1);
    lineWidth.push_back(1);
    lineWidth.push_back(1);
    
    // line colors
    vector<Int_t> lineColor;
    lineColor.push_back(1); 
    lineColor.push_back(1);
    lineColor.push_back(1);
    lineColor.push_back(1);
    lineColor.push_back(1);
    
    // line styles
    vector<Int_t> lineStyle;
    lineStyle.push_back(1); 
    lineStyle.push_back(1);
    lineStyle.push_back(1);
    lineStyle.push_back(1);
    lineStyle.push_back(2);

    // fill colors
    vector<Int_t> fillColor;
    fillColor.push_back(lineColor[0]); 
    fillColor.push_back(lineColor[1]);
    fillColor.push_back(lineColor[2]);
    fillColor.push_back(lineColor[3]);
    fillColor.push_back(lineColor[4]);

    // fill styles
    vector<Int_t> fillStyle;
    fillStyle.push_back(0); 
    fillStyle.push_back(3003);
    fillStyle.push_back(3004);
    fillStyle.push_back(3001);
    fillStyle.push_back(0);
    
    // legends
    vector<TString> legend;
    legend.push_back("2^{+}#rightarrow 0^{+}  (br = 1#times10^{-6})"); 
    legend.push_back("2^{+}#rightarrow 2^{+}"); 
    legend.push_back("#beta#gamma summing"); 
    legend.push_back("#beta#beta pile-up  (#tau = 1 #mus)");
    legend.push_back("CR background");
    
    // y axis
    Double_t ymin = 0;
    Double_t ymax = 20;
    Bool_t logy = true;
    if (logy) {
        ymin = 0.01;
        ymax = 1e3;
    }
    
	// Prepare canvas
    TCanvas *canvas = new TCanvas("c1", "canvas", 900, 700);
    canvas -> Clear();
	gROOT->SetStyle("Plain");
	gPad->UseCurrentStyle();
	gStyle->SetOptStat("");	
	gStyle->SetFillColor(-1); 
	gStyle->SetLegendBorderSize(0); 
	
	Int_t rf = 133; // times new roman, precision=3
	Int_t itf = 13; // italic times new roman, precision=3
	Float_t tsize = 30; // axes title size
	Float_t lsize = 25; // legend and label size
	Int_t lw = 1; // default line width
	
	// Legend
	Double_t xl1=.5, yl1=0.75, xl2=xl1+0.35, yl2=yl1+0.25;
    TLegend *leg = new TLegend(xl1, yl1, xl2, yl2);
    
	canvas->SetFrameBorderMode(0);
	canvas->SetBorderMode(0);
	canvas->SetFillColor(kWhite);
	canvas->SetLeftMargin(0.1); 

	Float_t xmarg = 0.005; // percent of canvas size
	Float_t ymarg = 0.005; // percent of canvas size
	canvas -> Divide(1, 1, xmarg, ymarg);

   	canvas->cd(1); 
   	canvas->cd(1)->SetBottomMargin(0.11); 
   	canvas->cd(1)->SetTopMargin(0.28); 
   	canvas->cd(1)->SetLeftMargin(0.15); 
    canvas->cd(1)->SetTicks(1,1);
    canvas->cd(1)->SetLogy(1);
    

    TFile *f = TFile::Open(ifname);
    
    // loop over histograms  
    for (Int_t i=0; i<hname.size(); i++) {

        // get histogram 
        TString hn = hname[i];
        TH1F *h = (TH1F*)gDirectory->Get(hn);  
        
        // set line and fill properties
        h -> SetLineWidth(lineWidth[i]);
        h -> SetLineColor(lineColor[i]);
        h -> SetLineStyle(lineStyle[i]);
        h -> SetFillColorAlpha(fillColor[i], 0.60); // 60% transparency
        h -> SetFillStyle(fillStyle[i]);

        // draw
        TString opt = "hist";
        if (i>0) opt = "samehist";
        h -> Draw(opt);

        // update canvas
        canvas -> Update();

        // "detach" the histograms from file and close file
        h -> SetDirectory(0); 

        // set log-y axis
        gPad -> SetLogy(logy);

        // integrals
        int binx1 = h->GetXaxis()->FindBin(ROImin);
        int binx2 = h->GetXaxis()->FindBin(ROImax);
        double counts = h->Integral(binx1, binx2);
        
        // legend
        TString label = "l";
        if (fillStyle[i] != 0) label = "f";
        leg -> AddEntry(h, legend[i] + Form(" [%.1f]", counts), label);  
        leg -> SetTextSize(lsize);
        leg -> SetTextFont(rf);
        leg -> SetFillColor(0);
        leg -> Draw("same");            
        
        // title
        h -> SetTitle("VETO spectrum");
        
        // get rid of stats
        h -> SetStats(kFALSE);

        // X axis
        TAxis * xax = h -> GetXaxis();
        xax->SetTitleColor(kBlack);
        xax->SetTitleFont(rf);
        xax->SetTitleSize(tsize);
        xax->SetLabelFont(rf);
        xax->SetLabelSize(lsize);
        TString s = Form("E (MeV)");
        xax->SetTitle(s);
        xax->SetTitleOffset(1);
        xax->SetLimits(xax->GetXmin()/1000, xax->GetXmax()/1000);  // keV -> MeV
        xax->SetRangeUser(xmin/1000, xmax/1000);

        // Y axis
        TAxis * yax = h -> GetYaxis();
        yax->SetTitleFont(rf);
        yax->SetLabelFont(rf);
        yax->SetTitleSize(tsize);
        yax->SetTitleColor(kBlack);
        yax->SetLabelSize(lsize);
        s = Form("Counts / 50 keV");
        yax->SetTitle(s);
        yax->SetTitleOffset(1.0);
        h->SetMinimum(ymin);
        h->SetMaximum(ymax);        
    }  
    
    Double_t xt = xmin + 0.0*(xmax-xmin);
    xt /= 1000;
    Double_t yt = 1.2*ymax;
    TLatex *t1 = new TLatex(xt, yt, "24 hours @ 30 kHz");  
    t1->SetTextSize(tsize);  
    t1->SetTextAngle(0);  
    t1->SetTextColor(1);  
    t1->SetTextFont(rf);  
    t1->Draw("same"); 

    xt = xmin + 0.0*(xmax-xmin);
    xt /= 1000;
    yt = 3.0*ymax;
    TLatex *t2 = new TLatex(xt, yt, Form("ROI: %.1f-%.1f MeV", ROImin/1000, ROImax/1000));  
    t2->SetTextSize(tsize);  
    t2->SetTextAngle(0);  
    t2->SetTextColor(1);  
    t2->SetTextFont(rf);  
    t2->Draw("same"); 


/*
    // TEXT
    Double_t xt = xmin;
    Double_t yt = 10*log10(ymax)/6.3 * ymax;
    Double_t incr = 2.5*log10(ymax)/6.3;
    
    TLatex *t1 = new TLatex(xt, yt, "B_{max} = 0.48 T");  
    t1->SetTextSize(tsize);  
    t1->SetTextAngle(0);  
    t1->SetTextColor(1);  
    t1->SetTextFont(rf);  
    t1->Draw("same"); 

    yt *= incr;
    t1 = new TLatex(xt, yt, "Duration = 1 week");  
    t1->SetTextSize(tsize);  
    t1->SetTextAngle(0);  
    t1->SetTextColor(1);  
    t1->SetTextFont(rf);  
    t1->Draw("same"); 

    yt *= incr;
    t1 = new TLatex(xt, yt, "^{20}F yield = 40 kHz");  
    t1->SetTextSize(tsize);  
    t1->SetTextAngle(0);  
    t1->SetTextColor(1);  
    t1->SetTextFont(rf);  
    t1->Draw("same"); 

*/ 
    f -> Close();

    canvas -> Print(ofname);

    TString fPng = "/home/oliskir/Desktop/specs/F20Spectrum.png";
    canvas->Print(fPng);     
}
